@@ -1,3 +1,5 @@
+import traceback
+
 from pypsql_api.config.types import Session
 from pypsql_api.wire.actions_types import Names
 from pypsql_api.context import Context
@@ -19,17 +21,22 @@ def write_ssl_resp_no(context: Context):
 
 
 def read_startup_message(context: Context):
-    startup_front = StartupMessage.read(context.input)
+    try:
+        startup_front = StartupMessage.read(context.input)
 
-    print(f"Got startup  {startup_front}")
+        print(f"Got startup  {startup_front}")
 
-    session = Session(
-        user=startup_front.user, database=startup_front.database, password=''
-    )
-
-    context.session = session
-    return context.update_mem('session', session), Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST
+        session = Session(
+            user=startup_front.user, database=startup_front.database, password=''
+        )
 
+        context.session = session
+        return context.update_mem('session', session), Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST
+    except:
+        print(f"Error udring startup read")
+        traceback.print_exc()
+        print("continuing with plain text password")
+        return context.update_mem('session', session), Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST
 
 def write_plain_text_password_request(context: Context):
     AuthenticationCleartextPassword().write(context.output)
